@@ -21,13 +21,13 @@ from zunclient.v1 import containers_shell
 
 def _get_container_args(**kwargs):
     default_args = {
-        'auto_heal': False,
         'auto_remove': False,
         'environment': {},
         'hints': {},
         'labels': {},
         'mounts': [],
         'nets': [],
+        'command': [],
     }
     default_args.update(kwargs)
     return default_args
